# pitchplots

library plotting charts for different tonal representation

## Getting Started

The program consist in the following files: musical_function.py, musical_read_file.py and static.py 

### Prerequisites

What things you need to install the software and how to install them

```
You will need python on your computer and the following libaries: matplotlib, pandas and numpy
```

note that if you are using anaconda, these libraries are already installed

### Installing

You can download the pitchplots package on pypi with pip using the following command in the prompt:

```
python3 -m pip install pitchplots
```

or if you're using anaconda prompt

```
pip install pitchplots
```

## Running the tests

you can test the library with test_pitchplots.py and data_pitchplots.csv

## Authors

* **Timothy Loayza** **Fabian Moss** - *Initial work* - [pitchplots](https://github.com/DCMLab/pitchplots)

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details